==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/society/dialogs_bg.lua <==
dialogId("mik-v-sakra", "font_big", "Dang, that snail is blocking the way.")
dialogStr("Лошо. Този охлюв блокира пътя.")

dialogId("mik-v-projet", "font_big", "I can’t swim through.")
dialogStr("Не мога да преплувам.")

dialogId("mik-m-krab", "font_small", "Those crabs are too talkative.")
dialogStr("Тези раци са твърде приказливи.")

dialogId("mik-m-poust", "font_small", "They don’t look like hermits.")
dialogStr("Не приличат на отшелници.")

dialogId("mik-m-tusit", "font_small", "I had no idea that hermit crabs could be so talkative.")
dialogStr("Нямах представа, че раците-отшелници са толкова приказливи.")

dialogId("mik-v-ticho0", "font_big", "Shut up!")
dialogStr("Млък!")

dialogId("mik-v-ticho1", "font_big", "Silence!")
dialogStr("Тишина!")

dialogId("mik-v-ticho2", "font_big", "What is it now?!")
dialogStr("Какво има пак?!")

dialogId("mik-v-proto", "font_big", "That’s better.")
dialogStr("Така е по-добре.")

dialogId("mik-v-tak", "font_big", "Yes.")
dialogStr("Да.")

dialogId("mik-m-nezlob", "font_small", "Don’t be mad at them.")
dialogStr("Не им се ядосвай.")

dialogId("mik-m-myslit", "font_small", "Now we can calmly ponder how to get out of here.")
dialogStr("Сега можем спокойно да обмислим как да се измъкнем.")

dialogId("mik-m-proc", "font_small", "White fish, why do you have such big eyes?")
dialogStr("Бяла рибо, защо са ти толкова големи очите?")

dialogId("mik-v-videt", "font_big", "All the better to see you with.")
dialogStr("За да те виждам по-добре, дете мое.")

dialogId("mik-m-konik", "font_small", "I’ve seen this seahorse somewhere before.")
dialogStr("И преди съм виждала някъде това морско конче.")

dialogId("mik-x-stebet0", "", "")
dialogStr("")

dialogId("mik-x-stebet1", "", "")
dialogStr("")

dialogId("mik-x-stebet2", "", "")
dialogStr("")

dialogId("mik-x-stebet3", "", "")
dialogStr("")

==> fillets-ng-data_1.0.1.orig.tar.gz: fillets-ng-data-1.0.1/script/society/dialogs_bg.lua <==
dialogId("mik-v-sakra", "font_big", "Dang, that snail is blocking the way.")
dialogStr("Лошо. Този охлюв блокира пътя.")

dialogId("mik-v-projet", "font_big", "I can’t swim through.")
dialogStr("Не мога да преплувам.")

dialogId("mik-m-krab", "font_small", "Those crabs are too talkative.")
dialogStr("Тези раци са твърде приказливи.")

dialogId("mik-m-poust", "font_small", "They don’t look like hermits.")
dialogStr("Не приличат на отшелници.")

dialogId("mik-m-tusit", "font_small", "I had no idea that hermit crabs could be so talkative.")
dialogStr("Нямах представа, че раците-отшелници са толкова бъбриви.")

dialogId("mik-v-ticho0", "font_big", "Shut up!")
dialogStr("Млък!")

dialogId("mik-v-ticho1", "font_big", "Silence!")
dialogStr("Тишина!")

dialogId("mik-v-ticho2", "font_big", "What is it now?!")
dialogStr("Какво има пак?!")

dialogId("mik-v-proto", "font_big", "That’s better.")
dialogStr("Така е по-добре.")

dialogId("mik-v-tak", "font_big", "Yes.")
dialogStr("Така.")

dialogId("mik-m-nezlob", "font_small", "Don’t be mad at them.")
dialogStr("Не им се ядосвай.")

dialogId("mik-m-myslit", "font_small", "Now we can calmly ponder how to get out of here.")
dialogStr("Сега можем спокойно да обмислим как да се измъкнем.")

dialogId("mik-m-proc", "font_small", "White fish, why do you have such big eyes?")
dialogStr("Бяла рибо, защо са ти толкова големи очите?")

dialogId("mik-v-videt", "font_big", "All the better to see you with.")
dialogStr("За да те виждам по-добре, дете мое.")

dialogId("mik-m-konik", "font_small", "I’ve seen this seahorse somewhere before.")
dialogStr("И преди съм виждала това морско конче.")

dialogId("mik-x-stebet0", "", "")
dialogStr("")

dialogId("mik-x-stebet1", "", "")
dialogStr("")

dialogId("mik-x-stebet2", "", "")
dialogStr("")

dialogId("mik-x-stebet3", "", "")
dialogStr("")
